# Python Lodash

pylodash is collection utilities allow you working with `List`, `Math`, `Number` and `String`

## Installation

You can install the Pylodash from [PyPI](https://pypi.org/project/pylodash/):

```
pip install pylodash
```

Pylodash is supported on Python 3.4 and above.

## How to use

You can call the Pylodash in your own Python code, by importing the `pylodash` package:

```
>>> from pylodash import arrays as _
>>> _.chunk(['a', 'b' , 'c', 'd'], 2)
// => [['a', 'b'], ['c', 'd']]
```